@@ -25,17 +25,17 @@
 
 from __future__ import print_function
 
-__revision__ = "src/script/sconsign.py 27552f9e8d59c13c3567f2bd380b74e34ee25324 2019-01-08 02:59:02 bdbaddog"
+__revision__ = "src/script/sconsign.py 3a41ed6b288cee8d085373ad7fa02894e1903864 2019-01-20 22:51:36 bdeegan"
 
-__version__ = "3.0.3"
+__version__ = "3.0.4"
 
-__build__ = "27552f9e8d59c13c3567f2bd380b74e34ee25324"
+__build__ = "3a41ed6b288cee8d085373ad7fa02894e1903864"
 
-__buildsys__ = "hpmicrodog"
+__buildsys__ = "kufra"
 
-__date__ = "2019-01-08 02:59:02"
+__date__ = "2019-01-20 22:51:36"
 
-__developer__ = "bdbaddog"
+__developer__ = "bdeegan"
 
 import os
 import sys
